aboutsummaryrefslogtreecommitdiff
path: root/config
diff options
context:
space:
mode:
Diffstat (limited to 'config')
-rw-r--r--config/p10k-classic.zsh5
-rw-r--r--config/p10k-lean.zsh5
-rw-r--r--config/p10k-rainbow.zsh5
3 files changed, 12 insertions, 3 deletions
diff --git a/config/p10k-classic.zsh b/config/p10k-classic.zsh
index 9fa60c40..10c58094 100644
--- a/config/p10k-classic.zsh
+++ b/config/p10k-classic.zsh
@@ -655,7 +655,10 @@
#############[ rbenv: ruby version from rbenv (https://github.com/rbenv/rbenv) ]##############
# Rbenv color.
typeset -g POWERLEVEL9K_RBENV_FOREGROUND=168
- # Don't show ruby version if it's the same as global: $(rbenv version-name) == $(rbenv global).
+ # Hide ruby version if it doesn't come from one of these sources.
+ typeset -g POWERLEVEL9K_RBENV_SOURCES=(shell local global)
+ # If set to false, hide ruby version if it's the same as global:
+ # $(rbenv version-name) == $(rbenv global).
typeset -g POWERLEVEL9K_RBENV_PROMPT_ALWAYS_SHOW=false
# Custom icon.
# typeset -g POWERLEVEL9K_RBENV_VISUAL_IDENTIFIER_EXPANSION='⭐'
diff --git a/config/p10k-lean.zsh b/config/p10k-lean.zsh
index 9f14440b..0e0b1c2a 100644
--- a/config/p10k-lean.zsh
+++ b/config/p10k-lean.zsh
@@ -631,7 +631,10 @@
#############[ rbenv: ruby version from rbenv (https://github.com/rbenv/rbenv) ]##############
# Rbenv color.
typeset -g POWERLEVEL9K_RBENV_FOREGROUND=168
- # Don't show ruby version if it's the same as global: $(rbenv version-name) == $(rbenv global).
+ # Hide ruby version if it doesn't come from one of these sources.
+ typeset -g POWERLEVEL9K_RBENV_SOURCES=(shell local global)
+ # If set to false, hide ruby version if it's the same as global:
+ # $(rbenv version-name) == $(rbenv global).
typeset -g POWERLEVEL9K_RBENV_PROMPT_ALWAYS_SHOW=false
# Custom icon.
# typeset -g POWERLEVEL9K_RBENV_VISUAL_IDENTIFIER_EXPANSION='⭐'
diff --git a/config/p10k-rainbow.zsh b/config/p10k-rainbow.zsh
index 070e4f5d..fddefbb2 100644
--- a/config/p10k-rainbow.zsh
+++ b/config/p10k-rainbow.zsh
@@ -669,7 +669,10 @@
# Rbenv color.
# typeset -g POWERLEVEL9K_RBENV_FOREGROUND=0
# typeset -g POWERLEVEL9K_RBENV_BACKGROUND=1
- # Don't show ruby version if it's the same as global: $(rbenv version-name) == $(rbenv global).
+ # Hide ruby version if it doesn't come from one of these sources.
+ typeset -g POWERLEVEL9K_RBENV_SOURCES=(shell local global)
+ # If set to false, hide ruby version if it's the same as global:
+ # $(rbenv version-name) == $(rbenv global).
typeset -g POWERLEVEL9K_RBENV_PROMPT_ALWAYS_SHOW=false
# Custom icon.
# typeset -g POWERLEVEL9K_RBENV_VISUAL_IDENTIFIER_EXPANSION='⭐'